@@ -37,16 +37,18 @@
 
 #ifndef _GNUstep_H_NSApplication
 #define _GNUstep_H_NSApplication
-#import <GNUstepBase/GSVersionMacros.h>
+#import <AppKit/AppKitDefines.h>
 
 #import <AppKit/NSResponder.h>
 #import <AppKit/NSUserInterfaceValidation.h>
+#import <AppKit/NSWindow.h>
 
 #if defined(__cplusplus)
 extern "C" {
 #endif
 
 @class NSArray;
+@class NSAppearance;
 @class NSDate;
 @class NSError;
 @class NSException;
@@ -62,6 +64,7 @@ extern "C" {
 @class NSMenuItem;
 @class NSPasteboard;
 @class NSWindow;
+@class NSDockTile;
 
 @class GSInfoPanel;
 
@@ -200,6 +203,7 @@ typedef enum _NSApplicationPresentationOptions
 APPKIT_EXPORT NSString	*NSModalPanelRunLoopMode;
 APPKIT_EXPORT NSString	*NSEventTrackingRunLoopMode;
 
+APPKIT_EXPORT_CLASS
 @interface NSApplication : NSResponder <NSCoding,NSUserInterfaceValidations>
 {
   NSGraphicsContext	*_default_context;
@@ -220,11 +224,13 @@ APPKIT_EXPORT NSString	*NSEventTrackingRunLoopMode;
   BOOL			_windows_need_update;
   NSImage		*_app_icon;
   NSWindow		*_app_icon_window;
+  NSDockTile            *_dock_tile;
   NSMutableArray	*_hidden;
   NSMutableArray	*_inactive;
   NSWindow		*_hidden_key;
   NSWindow              *_hidden_main;
   GSInfoPanel           *_infoPanel;
+  NSAppearance          *_appearance;
   NSApplicationPresentationOptions _presentationOptions;
 
   /* This autorelease pool should only be created and used by -run, with
@@ -777,16 +783,6 @@ NSShowSystemInfoPanel(NSDictionary *options);
  */
 APPKIT_EXPORT NSApplication	*NSApp;
 
-#if OS_API_VERSION(MAC_OS_X_VERSION_10_3, GS_API_LATEST)
-enum
-{
-  NSModalResponseStop = -1000,
-  NSModalResponseAbort = -1001,
-  NSModalResponseContinue = -1002
-};
-typedef NSInteger NSModalResponse;
-#endif
-
 #if defined(__cplusplus)
 }
 #endif
