@@ -32,11 +32,14 @@
 
 #ifndef _GNUstep_H_NSView
 #define _GNUstep_H_NSView
-#import <GNUstepBase/GSVersionMacros.h>
+#import <AppKit/AppKitDefines.h>
 
+#import <AppKit/NSAppearance.h>
 #import <AppKit/NSGraphicsContext.h>
 #import <AppKit/NSResponder.h>
+#import <AppKit/NSUserInterfaceItemIdentification.h>
 #import <AppKit/NSUserInterfaceLayout.h>
+#import <AppKit/NSLayoutConstraint.h>
 
 @class NSArray;
 @class NSAttributedString;
@@ -53,6 +56,7 @@
 @class NSScrollView;
 @class NSView;
 @class NSWindow;
+@class NSShadow;
 
 typedef NSInteger NSTrackingRectTag;
 typedef NSInteger NSToolTipTag;
@@ -112,6 +116,7 @@ enum {
   NSViewHeightSizable	= 16,	// view's height can stretch
   NSViewMaxYMargin	= 32 	// top margin between views can stretch
 };
+typedef NSUInteger NSAutoresizingMaskOptions;
 
 /*
  * constants defining if and how a view (or cell) should draw a focus ring
@@ -122,7 +127,11 @@ typedef enum _NSFocusRingType {
   NSFocusRingTypeExterior = 2
 } NSFocusRingType;
 
-@interface NSView : NSResponder
+extern const CGFloat NSViewNoInstrinsicMetric;
+extern const CGFloat NSViewNoIntrinsicMetric;
+
+APPKIT_EXPORT_CLASS
+@interface NSView : NSResponder <NSAppearanceCustomization, NSUserInterfaceItemIdentification>
 {
   NSRect _frame;
   NSRect _bounds;
@@ -130,6 +139,7 @@ typedef enum _NSFocusRingType {
   id _boundsMatrix;
   id _matrixToWindow;
   id _matrixFromWindow;
+  id _coreAnimationData;
 
   NSView* _super_view;
 PACKAGE_SCOPE
@@ -176,10 +186,19 @@ PACKAGE_SCOPE
   BOOL _renew_gstate;
   BOOL _is_hidden;
   BOOL _in_live_resize;
+  BOOL _needsLayout;
+  BOOL _needsUpdateConstraints;
+  BOOL _translatesAutoresizingMaskIntoConstraints;
+  float _contentCompressionResistancePriority;
+  GSIntrinsicContentSizePriority _huggingPriorities;
+  GSIntrinsicContentSizePriority _compressionPriorities;
 
   NSUInteger _autoresizingMask;
   NSFocusRingType _focusRingType;
   NSRect _autoresizingFrameError;
+  NSShadow *_shadow;
+  NSAppearance* _appearance;
+  NSUserInterfaceItemIdentifier _identifier;
 }
 
 /*
@@ -638,8 +657,103 @@ PACKAGE_SCOPE
 #endif
 #endif
 
+/**
+* Layout
+*/
+
+#if OS_API_VERSION(MAC_OS_X_VERSION_10_7, GS_API_LATEST)
+- (void) layoutSubtreeIfNeeded;
+- (void) layout;
+
+#if GS_HAS_DECLARED_PROPERTIES
+@property (nonatomic) BOOL needsLayout;
+#else
+- (BOOL) needsLayout;
+- (void) setNeedsLayout: (BOOL)needsLayout;
+#endif
+
+#if GS_HAS_DECLARED_PROPERTIES
+@property (nonatomic) BOOL needsUpdateConstraints;
+#else
+- (BOOL) needsUpdateConstraints;
+- (void) setNeedsUpdateConstraints: (BOOL)needsUpdateConstraints;
+#endif
+
+#if GS_HAS_DECLARED_PROPERTIES
+@property BOOL translatesAutoresizingMaskIntoConstraints;
+#else
+- (BOOL) translatesAutoresizingMaskIntoConstraints;
+- (void) setTranslatesAutoresizingMaskIntoConstraints: (BOOL)translatesAutoresizingMaskIntoConstraints;
+#endif
+
+#if GS_HAS_DECLARED_PROPERTIES
+@property float contentCompressionResistancePriority;
+#else
+- (BOOL) contentCompressionResistancePriority;
+- (void) setContentCompressionResistancePriority: (NSLayoutPriority)priority;
+#endif
+
+#if GS_HAS_DECLARED_PROPERTIES
+@property (readonly) NSSize intrinsicContentSize;
+#else
+- (BOOL) intrinsicContentSize;
+#endif
+
+#if GS_HAS_DECLARED_PROPERTIES
+@property (readonly) CGFloat baselineOffsetFromBottom;
+#else
+- (CGFloat) baselineOffsetFromBottom;
+#endif
+
+#if GS_HAS_DECLARED_PROPERTIES
+@property (readonly) CGFloat firstBaselineOffsetFromTop;
+#else
+- (CGFloat) firstBaselineOffsetFromTop;
+#endif
+
+#endif
+
 @end
 
+#if OS_API_VERSION(MAC_OS_X_VERSION_10_7, GS_API_LATEST)
+@interface NSView (NSConstraintBasedLayoutCoreMethods)
+
+- (void) updateConstraints;
+
+- (void) updateConstraintsForSubtreeIfNeeded;
+
+- (NSLayoutPriority) contentHuggingPriorityForOrientation: (NSLayoutConstraintOrientation)orientation;
+
+- (void) setContentHuggingPriority: (NSLayoutPriority)priority forOrientation: (NSLayoutConstraintOrientation)orientation;
+
+- (NSLayoutPriority) contentCompressionResistancePriorityForOrientation: (NSLayoutConstraintOrientation)orientation;
+
+- (void)setContentCompressionResistancePriority: (NSLayoutPriority)priority forOrientation: (NSLayoutConstraintOrientation)orientation;
+
+@end
+
+@interface NSView (NSConstraintBasedLayoutInstallingConstraints)
+
+- (void) addConstraint: (NSLayoutConstraint *)constraint;
+
+- (void) addConstraints: (NSArray*)constraints;
+
+@end
+#endif
+
+#if OS_API_VERSION(MAC_OS_X_VERSION_10_5, GS_API_LATEST)
+/*
+ * Core Animation support methods.  More methods will be added here as more are implemented.
+ */
+
+@interface NSView (CoreAnimationSupport)
+
+- (NSShadow *) shadow;
+
+- (void) setShadow: (NSShadow *)shadow;
+
+@end
+#endif
 
 @class NSAffineTransform;
 
